run

Function run 

pub fn run(
    whisker_rs: &Path,
    crate_dir: &Path,
    crate_name: &str,
) -> Result<Config>
Run the probe and return the parsed config. Caches via mtime so the second call (and later) returns instantly until whisker.rs changes.

crate_name is used to name the probe binary (so the temp target/ doesn’t collide if the user happens to also have a probe-shaped crate of their own).